//! # Webauthn config
//!
//! @author Pierre Hubert

use webauthn_rs::{Webauthn, WebauthnConfig};

use crate::data::config::conf;

pub struct ComunicAdminWebauthnConfig {
    origin: url::Url,
    relying_party_id: String,
}

impl WebauthnConfig for ComunicAdminWebauthnConfig {
    fn get_relying_party_name(&self) -> &str {
        "ComunicAdmin"
    }

    fn get_origin(&self) -> &url::Url {
        &self.origin
    }

    fn get_relying_party_id(&self) -> &str {
        &self.relying_party_id
    }
}

pub fn get_wan() -> Webauthn<ComunicAdminWebauthnConfig> {
    Webauthn::new(ComunicAdminWebauthnConfig {
        origin: url::Url::parse(&conf().admin_url).unwrap(),
        relying_party_id: conf().admin_url
            .replace("https://", "")
            .replace("http://", "")
            .split(":")
            .next()
            .unwrap()
            .split("/")
            .next()
            .unwrap()
            .to_string(),
    })
}